<!DOCTYPE html>
<html>
<head>
	<link rel='stylesheet' type="text/css" href="{{ url_for('static',filename='styles/style.css') }}">
	<script src="{{url_for('static', filename='index.js')}}"></script>
	<title>inSPIRE-Interactive</title>
</head>
<body>
	{{ inspire_header|safe }}
    <!-- top section -->
    <dev class = "contact-main-section">
        <dev class = "contact-top-section">
             <p> inSPIRE Help & Support
             </p>
        </dev>
    </dev>
    <dev class = "contact-main-section">
        <dev class = "contact-top-section-description" style="height:200px;"> 
            <p>
                Our prefered method for standard issues is to open an issue on the
                <a href="https://github.com/QuantSysBio/inSPIRE/issues">inSPIRE Github</a>
                page. This is a public forum that allows others to learn if you have made
                a mistake and allows our developers to track problems on our side.
                <br></br>
                If you are working with sensitive data and are nervous about posting on
                a public forum or if you are interested in on site support or collaboration
                you can contact us via email on qsb.support@mpinat.mpg.de or just directly fill the form below with your queries / comments.
            </p>

    
        </dev>
    </dev>

    {{ inspire_footer|safe }}
</body>
</html>
