<!DOCTYPE html>
<html>
<head>
	<link rel='stylesheet' type="text/css" href="{{ url_for('static',filename='styles/style.css') }}">
	<script src="{{url_for('static', filename='index.js')}}"></script>
	<title>inSPIRE-Interactive</title>
</head>
<body>
	<dev class = "page-wrapper">
	<!-- header -->
	{{ inspire_header|safe }}
	<hr>
	<table class="results-table">

		<div class="res-row">
			<div style="margin-left: 15%; padding-right:6%; width:500px;" class="res-column">
				<h2>inSPIRE Identification Results</h2>
				<p id="psm-fdr-increase">{{ inspire_increase }}</p>
				Click to download all identifications on
				<a href="http://{{ server_address }}:5000/interact/get_results/{{ user }}/{{ project }}/psms">
					PSM level</a> or
				<a href="http://{{ server_address }}:5000/interact/get_results/{{ user }}/{{ project }}/peptides">
					peptide level</a>
				or
				<a href="http://{{ server_address }}:5000/interact/get_results/{{ user }}/{{ project }}/performance">click to view the inSPIRE performance report</a>		
				<br>
				<br>
				{{ psm_fdr_html|safe }}
				<br>
			</div>

			<div class="res-column" style="width: 500px;">
				<h2>inSPIRE Quantitative Report</h2>
				<p id="psm-fdr-increase">{{ inspire_quantified_count }}</p>

				<a href="http://{{ server_address }}:5000/interact/get_results/{{ user }}/{{ project }}/quantification">
					Click to download the quantification zip file
				</a>
				or
				<a href="http://{{ server_address }}:5000/interact/get_results/{{ user }}/{{ project }}/quantReport">click to view the inSPIRE quantitative report</a>
				<br>
				<br>
				{{ quant_html|safe }}
			</div>
		</div>

		<div class="res-row">
			<div id="inSpirePerformance" style="visibility: {{ inspire_select_visible }}; margin-left: 15%; ; padding-right:6%; width:500px;"  class="res-column">
				<h2>inSPIRE-Pathogen Results</h2>
				<p id="inspire-pathogen-increase">{{ pathogen_increase }}</p>
				<a href="http://{{ server_address }}:5000/interact/get_results/{{ user }}/{{ project }}/inspirePathogen">
					Click to download the zip file with all epitope information
				</a> or
				<a href="http://{{ server_address }}:5000/interact/get_results/{{ user }}/{{ project }}/epitopeReport">
					click to view the inSPIRE epitope report
				</a>
				<br>
				<br>
				{{ ep_bar|safe }}
			</div>

			<div class="res-column" style="width: 500px;">
				<h2>inSPIRE Execution Logs</h2>
				<p>Here you can see the details of inSPIRE execution</p>
				<a href="http://{{ server_address }}:5000/interact/get_results/{{ user }}/{{ project }}/inspireLog"> Click to download the log of inSPIRE execution</a>
				or
				<a href="http://{{ server_address }}:5000/interact-page/parameters/{{ user }}/{{ project }}">click to re-execute the pipeline with alternative parameters.</a>
				<br>
				<br>
				{{ progress_html|safe }}
			</div>
		</table>
	</div>
	<br><br>

	{{ inspire_footer|safe }}

	</dev>
</body>
</html>
