<!DOCTYPE html>
<html>
<head>
	<link rel='stylesheet' type="text/css" href="{{ url_for('static',filename='styles/style.css') }}">
	<script src="{{url_for('static', filename='index.js')}}"></script>
	<title>inSPIRE-Interactive</title>
</head>
<body>
	{{ inspire_header|safe }}

    <h3>Error 404: The requested resource is unavailable, check your username and project details.</h3>
</body>
</html>
