<!DOCTYPE html>
<html>
<head>
	<link rel='stylesheet' type="text/css" href="{{ url_for('static',filename='styles/style.css') }}">
	<script src="{{url_for('static', filename='index.js')}}"></script>
	<title>inSPIRE-Interactive</title>
</head>
<body>
	<dev class = "page-wrapper">
	
		<!-- header -->
		{{ inspire_header|safe }}

		<div class = "download-div">
			<div style=" width:1404px; text-align: center; background:linear-gradient(to left, rgb(248, 215, 210) 30%, #FFFFFF 100%); ">
			   <p><b>Attention !!!</b></p>
		   </div>
	   </div>
	   <br>
	   <br>
	   <br>
	   <p style = " font-size:x-large; text-align:center; align-items: center;"> <b>Are you sure you want to delete this project? If yes, click below.</b></p>
	   
	   	<div class="vertical-center">
			<button class="delete-button" onclick="deleteProject('{{ server_address }}', '{{ user }}', '{{ project }}')">
				Delete All Project Data
			</button>
		</div>
	   
		

	{{ inspire_footer|safe }}

</dev>
</body>
</html>
