<!DOCTYPE html>
<html>
<head>
	<link rel='stylesheet' type="text/css" href="{{ url_for('static',filename='styles/style.css') }}">
	<script src="{{url_for('static', filename='index.js')}}"></script>
	<title>inSPIRE-Interactive</title>
</head>
<body>
	<dev class = "page-wrapper">
		{{ inspire_header|safe }}

		<div class = "download-div">
			<div style=" width:1404px; text-align: center; background: linear-gradient(to left, rgb(188, 245, 226) 30%, #FFFFFF 100%);  ">
			   <p style = "color:red"><b>Unfortunately your inSPIRE job has failed. </b></p>
		   </div>
	   </div>
	   <br><br>

	   <center>
			<h2>Progress Log</h2>
			{{ progress_html|safe }}
		</center>

		<div style = "display:flex;flex-direction: column; text-align: center; font-size: larger; justify-content:space-evenly; align-items:center;height:420px;">
			<a href="http://{{ server_address }}:5000/interact/get_results/{{ user }}/{{ project }}/inspireLog"> 
				<button class="download-button" style= " margin:0; width:550px; height: 80px; font-size: larger;">
					Click to Download the log of inSPIRE execution.
				</button></a>
			or<br>
			<a href="http://{{ server_address }}:5000/interact-page/parameters/{{ user }}/{{ project }}">
				<button class="download-button" style= "margin:0; width:650px; height: 80px; font-size: larger;">
					Click to re-execute the pipeline with alternative parameters.
				</button></a>
			<br>
		</div>
		<!--<center>
			<h2>Progress Log</h2>
			{{ progress_html|safe }}
		</center>

		<br><br>-->

        {{ inspire_footer|safe }}
	</dev>
</body>
</html>
