<!DOCTYPE html>
<html>
<head>
	<link rel='stylesheet' type="text/css" href="{{ url_for('static',filename='styles/style.css') }}">
	<script src="{{url_for('static', filename='index.js')}}"></script>
	<title>inSPIRE-Interactive</title>
</head>
<body>
	<dev class = "page-wrapper">
		<!-- header -->
		{{ inspire_header|safe }}
		<hr>
		<p class="adjusted-text">Your data is still processing, check again later.</p>
		
		<center>
			<h2>Progress Log</h2>
			{{ progress_html|safe }}
		</center>
		<div class="adjusted-text">
			<p>If you have made a mistake and wish to cancel your job, click below.</p>
			<div class="vertical-center">
				<button id="execute-button" class="job-button" onclick="cancelPipeline('{{ server_address }}', '{{ user }}', '{{ project }}')">
					Cancel Exectuions
				</button>
			</div>
			<div id="cancelled-text"></div>
		</div>
		<br><br>

		{{ inspire_footer|safe }}
	</dev>
</body>
</html>
